| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeigootsvqpk6th5xpdtzanxum3earifrrezfyhylfrit7yvqdrtgpe` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeigqurc4jzjqjs4ptbfz4r4qk6ued2tdw4op3zjnal645fbk4aikya` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeighbvg6if7bwswosgajlzgz36pwuyttu3vyfqgwi3xayvdxtl53lq` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeihlc3keplnos7vnlibehpt2rvfhlljyshbsvhbkwgyhgdvqublzeq` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeigklynwl3mfav5yt5zdkrqe6rukv4ygdhpdusk66ojt4jj7tunxcy` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeielrs5qih3r6qhnily6x4h4j4j6kux6eqr546homow4c5ljgfyljq` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeihcilb27ekgoplmc43iog2zrus63fufql4rly2umbuj573nu3zpg4` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeid4ufdirr3qaksk72iwnuzfelhzqwh7t3q56x2ixhzvwltte4yy5a` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeidsj2kfj2o7sh5mj6pz7ftrg72edqkij3fbuxkpkvzxuoqdzgd4i4` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeib2myejevrwusvucak2fk5hx5qafzjwtnxvbkddldtgzexnwk64ni` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeift7qksgjuqh67abas3gfbfwwwvhv6tj3lvgzv5wc2nrlnoe65ba4` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeidjqmwvgi4rqgp65tbkhmi45fwn2odr5ecezw6q47hwitsgyw4jpa` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeibjzhsengtxfofqpxy6syamplevp35obemwfp4c5lhag3v2bvgysa` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeigopohwdk5m2kuk76dbwlokpdvxtxadgda5vq52i54ofpnndlwwuy` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeicetxwbgfqxcaoack7knljqo4i6up4nqgvm272eyqdqii4hcis5ri` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeicqwr73cs3vndzafrjrjpw63vvqbbjsur7ptek77hsw3lurnood5y` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeidfktuprydtmi4umolfles5qaf7s3t26puvvs44hvkq6uwwr3ia3a` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeicisazpyvnnzlqso3txiucxr5qhsa4ac7ius6b4mhouxr2wkadwfy` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeiggzuqokgt7itc6ekb5ylmdylvfbhxqxylyz4p62qah2lkjstgdwe` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeiblayblhp5wuirfomwcpgydg35ve5tfq3xxetlosjn47wva5ucmzy` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeieqfhvk6klnvxak3vo2ibslkrnnk2bfsn5l3gbaelcprd6cjngxki` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeidcjzsf7y7ni4z7apngrwecpi7562i6n6chun3hwjtbojnq3x2dci` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeianskoghhdffn4wqquup3rtziefq6jareutugb6a5zkbvuvctgk3i` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeif7lzot5lh4zbomho2nyxh4l56grcrmuikqp5khas6z7rbwzw5cnq` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeic24xniwheivtobqjowezwbcmvikvurvsnil2iv36khfr2zwmpfiu` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeibyh32rpnmioqb2jxxqf5fnpa74agu5e5zffr6vilwq45lngfjgfa` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeif7bxthxuclmhxq5gdrvdfegdqxlr2jfcxagafbe6kwpsxa5i5qie` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeif3yvli3eonmf6yojxjzj7qgig47xhmg76zoihodcsbhqigqxj54m` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeigsajfhcox22vrlqsodmi6y5l2jwx7xnzhhu4wbguqoas22ooqafq` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeihwqpwbejtk25xvlsltinpxe5myb33vpv4ee7qxqgsbwuzkdzujoe` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeihh7xeqm673zgspnv6edspsw7ta3lvhknwjrdz4o7ww6cvimapqyy` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeibit5dfccbcxxoexlwb36cro5imywlgm6cwc74jomu52ulrjucbhq` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeiclvirlrxynkrhlj7smmw2ubk756b72mhwzvaiwkzpiwlzczmvkuq` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeifwvunfi6uf3bkv5zbw5ckgl7m6px6zspsnkebbqiag7zcpdwft2e` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeido3s7okni7nnvw7orzf4buumfmyhvjy6p2bhznux7xxbz2l5rgae` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeicn5ikxm3wthdxja26bciifpkjrrb455y4whcxvyto4a7tpfvyz4e` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeibao4o6x2b5qrfe5zo2ksz2skhv2sgazhoixz67l5ndwbomjq6sv4` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeiaiedkufei6vqp7p6pznp7z2klrlzullqz2jlzvqgnakyu5cmg22y` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeidi3v747exsmoy6qbnis4z3avozpflqk7n23w5hbmhijo2k5kfv74` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeibone4sts543o2s2fj5ipnsdw5mlburnqseifjbs2vmkv65uvf3ky` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeihhn3vic2yje7ehmi43a4wus4vnei5nwihetwk73tqtgbnn44pr2u` | The MakerDAO multicall2 contract.                                                                                          |
| skill/valory/slashing_abci/0.1.0                              | `bafybeih2q3hatumfrd2me75djo6vm6t5zjpn4pi4sx2dguyrymtg47vjru` | Slashing skill.                                                                                                            |
| skill/valory/offend_abci/0.1.0                                | `bafybeibmlwjfv4ttq2htq2o2g3pef5t3pawgmdt5td6wt5axjxgowk3ezu` | Offend ABCI application.                                                                                                   |
| skill/valory/offend_slash_abci/0.1.0                          | `bafybeicpxjwi6soefemt3yjuo22yols3xhslf4dnwpumnmq7b6wyjmtbxi` | ABCI application used in order to test the slashing abci                                                                   |
| agent/valory/offend_slash/0.1.0                               | `bafybeigrvq2jmgcc6aaeza4at34s2eb6d47vufxr6fzlhgf22bxm6iw5tu` | Offend and slash to test the slashing feature.                                                                             |
| contract/valory/erc20/0.1.0                                   | `bafybeiag7wpfri44bwrx26374mnxyglmwxod6gu37foqkvloqr7oeldlgu` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/service_registry_token_utility/0.1.0          | `bafybeifdia2y5546tvk6xzxeaqzf2n5n7dutj2hdzbgenxohaqhjtnjqm4` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| protocol/open_aea/signing/1.0.0                               | `bafybeifuxs7gdg2okbn7uofymenjlmnih2wxwkym44lsgwmklgwuckxm2m` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeiapa5ilsobggnspoqhspftwolrx52udrwmaxdxgrk26heuvl4oooa` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeia5bxdua2i6chw6pg47bvoljzcpuqxzy4rdrorbdmcbnwmnfdobtu` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeigsvceac33asd6ecbqev34meyyjwu3rangenv6xp5rkxyz4krvcby` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeiasywsvax45qmugus5kxogejj66c5taen27h4voriodz7rgushtqa` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeieoeuy4brzimtnubmokwirhrx27ezls6cdnl5qik4rkykfle3nn2y` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeigfoz7d7si7s4jehvloq2zmiiocpbxcaathl3bxkyarxoerxq7g3a` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeihdnfdth3qgltefgrem7xyi4b3ejzaz67xglm2hbma2rfvpl2annq` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
